# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import enum

import winrt.system
from winrt._winrt_windows_ui_xaml_automation_peers import (
    RawElementProviderRuntimeId,
    AppBarAutomationPeer,
    AppBarButtonAutomationPeer,
    AppBarToggleButtonAutomationPeer,
    AutoSuggestBoxAutomationPeer,
    AutomationPeer,
    AutomationPeerAnnotation,
    ButtonAutomationPeer,
    ButtonBaseAutomationPeer,
    CalendarDatePickerAutomationPeer,
    CaptureElementAutomationPeer,
    CheckBoxAutomationPeer,
    ColorPickerSliderAutomationPeer,
    ColorSpectrumAutomationPeer,
    ComboBoxAutomationPeer,
    ComboBoxItemAutomationPeer,
    ComboBoxItemDataAutomationPeer,
    DatePickerAutomationPeer,
    DatePickerFlyoutPresenterAutomationPeer,
    FlipViewAutomationPeer,
    FlipViewItemAutomationPeer,
    FlipViewItemDataAutomationPeer,
    FlyoutPresenterAutomationPeer,
    FrameworkElementAutomationPeer,
    GridViewAutomationPeer,
    GridViewHeaderItemAutomationPeer,
    GridViewItemAutomationPeer,
    GridViewItemDataAutomationPeer,
    GroupItemAutomationPeer,
    HubAutomationPeer,
    HubSectionAutomationPeer,
    HyperlinkButtonAutomationPeer,
    ImageAutomationPeer,
    InkToolbarAutomationPeer,
    ItemAutomationPeer,
    ItemsControlAutomationPeer,
    ListBoxAutomationPeer,
    ListBoxItemAutomationPeer,
    ListBoxItemDataAutomationPeer,
    ListPickerFlyoutPresenterAutomationPeer,
    ListViewAutomationPeer,
    ListViewBaseAutomationPeer,
    ListViewBaseHeaderItemAutomationPeer,
    ListViewHeaderItemAutomationPeer,
    ListViewItemAutomationPeer,
    ListViewItemDataAutomationPeer,
    LoopingSelectorAutomationPeer,
    LoopingSelectorItemAutomationPeer,
    LoopingSelectorItemDataAutomationPeer,
    MapControlAutomationPeer,
    MediaElementAutomationPeer,
    MediaPlayerElementAutomationPeer,
    MediaTransportControlsAutomationPeer,
    MenuBarAutomationPeer,
    MenuBarItemAutomationPeer,
    MenuFlyoutItemAutomationPeer,
    MenuFlyoutPresenterAutomationPeer,
    NavigationViewItemAutomationPeer,
    PasswordBoxAutomationPeer,
    PersonPictureAutomationPeer,
    PickerFlyoutPresenterAutomationPeer,
    PivotAutomationPeer,
    PivotItemAutomationPeer,
    PivotItemDataAutomationPeer,
    ProgressBarAutomationPeer,
    ProgressRingAutomationPeer,
    RadioButtonAutomationPeer,
    RangeBaseAutomationPeer,
    RatingControlAutomationPeer,
    RepeatButtonAutomationPeer,
    RichEditBoxAutomationPeer,
    RichTextBlockAutomationPeer,
    RichTextBlockOverflowAutomationPeer,
    ScrollBarAutomationPeer,
    ScrollViewerAutomationPeer,
    SearchBoxAutomationPeer,
    SelectorAutomationPeer,
    SelectorItemAutomationPeer,
    SemanticZoomAutomationPeer,
    SettingsFlyoutAutomationPeer,
    SliderAutomationPeer,
    TextBlockAutomationPeer,
    TextBoxAutomationPeer,
    ThumbAutomationPeer,
    TimePickerAutomationPeer,
    TimePickerFlyoutPresenterAutomationPeer,
    ToggleButtonAutomationPeer,
    ToggleMenuFlyoutItemAutomationPeer,
    ToggleSwitchAutomationPeer,
    TreeViewItemAutomationPeer,
    TreeViewListAutomationPeer,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winrt._winrt_windows_ui_xaml_automation_peers import (
        AppBarAutomationPeer_Static,
        AppBarButtonAutomationPeer_Static,
        AppBarToggleButtonAutomationPeer_Static,
        AutomationPeer_Static,
        ButtonAutomationPeer_Static,
        ButtonBaseAutomationPeer_Static,
        CalendarDatePickerAutomationPeer_Static,
        CaptureElementAutomationPeer_Static,
        CheckBoxAutomationPeer_Static,
        ColorPickerSliderAutomationPeer_Static,
        ColorSpectrumAutomationPeer_Static,
        ComboBoxAutomationPeer_Static,
        ComboBoxItemAutomationPeer_Static,
        ComboBoxItemDataAutomationPeer_Static,
        DatePickerAutomationPeer_Static,
        FlipViewAutomationPeer_Static,
        FlipViewItemAutomationPeer_Static,
        FlipViewItemDataAutomationPeer_Static,
        FlyoutPresenterAutomationPeer_Static,
        FrameworkElementAutomationPeer_Static,
        GridViewAutomationPeer_Static,
        GridViewHeaderItemAutomationPeer_Static,
        GridViewItemAutomationPeer_Static,
        GridViewItemDataAutomationPeer_Static,
        GroupItemAutomationPeer_Static,
        HubAutomationPeer_Static,
        HubSectionAutomationPeer_Static,
        HyperlinkButtonAutomationPeer_Static,
        ImageAutomationPeer_Static,
        ItemAutomationPeer_Static,
        ItemsControlAutomationPeer_Static,
        ListBoxAutomationPeer_Static,
        ListBoxItemAutomationPeer_Static,
        ListBoxItemDataAutomationPeer_Static,
        ListViewAutomationPeer_Static,
        ListViewBaseAutomationPeer_Static,
        ListViewBaseHeaderItemAutomationPeer_Static,
        ListViewHeaderItemAutomationPeer_Static,
        ListViewItemAutomationPeer_Static,
        ListViewItemDataAutomationPeer_Static,
        MediaElementAutomationPeer_Static,
        MediaPlayerElementAutomationPeer_Static,
        MediaTransportControlsAutomationPeer_Static,
        MenuBarAutomationPeer_Static,
        MenuBarItemAutomationPeer_Static,
        MenuFlyoutItemAutomationPeer_Static,
        MenuFlyoutPresenterAutomationPeer_Static,
        NavigationViewItemAutomationPeer_Static,
        PasswordBoxAutomationPeer_Static,
        PersonPictureAutomationPeer_Static,
        ProgressBarAutomationPeer_Static,
        ProgressRingAutomationPeer_Static,
        RadioButtonAutomationPeer_Static,
        RangeBaseAutomationPeer_Static,
        RatingControlAutomationPeer_Static,
        RepeatButtonAutomationPeer_Static,
        RichEditBoxAutomationPeer_Static,
        RichTextBlockAutomationPeer_Static,
        RichTextBlockOverflowAutomationPeer_Static,
        ScrollBarAutomationPeer_Static,
        ScrollViewerAutomationPeer_Static,
        SearchBoxAutomationPeer_Static,
        SelectorAutomationPeer_Static,
        SelectorItemAutomationPeer_Static,
        SemanticZoomAutomationPeer_Static,
        SettingsFlyoutAutomationPeer_Static,
        SliderAutomationPeer_Static,
        TextBlockAutomationPeer_Static,
        TextBoxAutomationPeer_Static,
        ThumbAutomationPeer_Static,
        TimePickerAutomationPeer_Static,
        ToggleButtonAutomationPeer_Static,
        ToggleMenuFlyoutItemAutomationPeer_Static,
        ToggleSwitchAutomationPeer_Static,
        TreeViewItemAutomationPeer_Static,
        TreeViewListAutomationPeer_Static,
    )

__all__ = [
    "AccessibilityView",
    "AutomationControlType",
    "AutomationEvents",
    "AutomationHeadingLevel",
    "AutomationLandmarkType",
    "AutomationLiveSetting",
    "AutomationNavigationDirection",
    "AutomationNotificationKind",
    "AutomationNotificationProcessing",
    "AutomationOrientation",
    "AutomationStructureChangeType",
    "PatternInterface",
    "RawElementProviderRuntimeId",
    "AppBarAutomationPeer",
    "AppBarButtonAutomationPeer",
    "AppBarToggleButtonAutomationPeer",
    "AutoSuggestBoxAutomationPeer",
    "AutomationPeer",
    "AutomationPeerAnnotation",
    "ButtonAutomationPeer",
    "ButtonBaseAutomationPeer",
    "CalendarDatePickerAutomationPeer",
    "CaptureElementAutomationPeer",
    "CheckBoxAutomationPeer",
    "ColorPickerSliderAutomationPeer",
    "ColorSpectrumAutomationPeer",
    "ComboBoxAutomationPeer",
    "ComboBoxItemAutomationPeer",
    "ComboBoxItemDataAutomationPeer",
    "DatePickerAutomationPeer",
    "DatePickerFlyoutPresenterAutomationPeer",
    "FlipViewAutomationPeer",
    "FlipViewItemAutomationPeer",
    "FlipViewItemDataAutomationPeer",
    "FlyoutPresenterAutomationPeer",
    "FrameworkElementAutomationPeer",
    "GridViewAutomationPeer",
    "GridViewHeaderItemAutomationPeer",
    "GridViewItemAutomationPeer",
    "GridViewItemDataAutomationPeer",
    "GroupItemAutomationPeer",
    "HubAutomationPeer",
    "HubSectionAutomationPeer",
    "HyperlinkButtonAutomationPeer",
    "ImageAutomationPeer",
    "InkToolbarAutomationPeer",
    "ItemAutomationPeer",
    "ItemsControlAutomationPeer",
    "ListBoxAutomationPeer",
    "ListBoxItemAutomationPeer",
    "ListBoxItemDataAutomationPeer",
    "ListPickerFlyoutPresenterAutomationPeer",
    "ListViewAutomationPeer",
    "ListViewBaseAutomationPeer",
    "ListViewBaseHeaderItemAutomationPeer",
    "ListViewHeaderItemAutomationPeer",
    "ListViewItemAutomationPeer",
    "ListViewItemDataAutomationPeer",
    "LoopingSelectorAutomationPeer",
    "LoopingSelectorItemAutomationPeer",
    "LoopingSelectorItemDataAutomationPeer",
    "MapControlAutomationPeer",
    "MediaElementAutomationPeer",
    "MediaPlayerElementAutomationPeer",
    "MediaTransportControlsAutomationPeer",
    "MenuBarAutomationPeer",
    "MenuBarItemAutomationPeer",
    "MenuFlyoutItemAutomationPeer",
    "MenuFlyoutPresenterAutomationPeer",
    "NavigationViewItemAutomationPeer",
    "PasswordBoxAutomationPeer",
    "PersonPictureAutomationPeer",
    "PickerFlyoutPresenterAutomationPeer",
    "PivotAutomationPeer",
    "PivotItemAutomationPeer",
    "PivotItemDataAutomationPeer",
    "ProgressBarAutomationPeer",
    "ProgressRingAutomationPeer",
    "RadioButtonAutomationPeer",
    "RangeBaseAutomationPeer",
    "RatingControlAutomationPeer",
    "RepeatButtonAutomationPeer",
    "RichEditBoxAutomationPeer",
    "RichTextBlockAutomationPeer",
    "RichTextBlockOverflowAutomationPeer",
    "ScrollBarAutomationPeer",
    "ScrollViewerAutomationPeer",
    "SearchBoxAutomationPeer",
    "SelectorAutomationPeer",
    "SelectorItemAutomationPeer",
    "SemanticZoomAutomationPeer",
    "SettingsFlyoutAutomationPeer",
    "SliderAutomationPeer",
    "TextBlockAutomationPeer",
    "TextBoxAutomationPeer",
    "ThumbAutomationPeer",
    "TimePickerAutomationPeer",
    "TimePickerFlyoutPresenterAutomationPeer",
    "ToggleButtonAutomationPeer",
    "ToggleMenuFlyoutItemAutomationPeer",
    "ToggleSwitchAutomationPeer",
    "TreeViewItemAutomationPeer",
    "TreeViewListAutomationPeer",
]

class AccessibilityView(enum.IntEnum):
    RAW = 0
    CONTROL = 1
    CONTENT = 2

class AutomationControlType(enum.IntEnum):
    BUTTON = 0
    CALENDAR = 1
    CHECK_BOX = 2
    COMBO_BOX = 3
    EDIT = 4
    HYPERLINK = 5
    IMAGE = 6
    LIST_ITEM = 7
    LIST = 8
    MENU = 9
    MENU_BAR = 10
    MENU_ITEM = 11
    PROGRESS_BAR = 12
    RADIO_BUTTON = 13
    SCROLL_BAR = 14
    SLIDER = 15
    SPINNER = 16
    STATUS_BAR = 17
    TAB = 18
    TAB_ITEM = 19
    TEXT = 20
    TOOL_BAR = 21
    TOOL_TIP = 22
    TREE = 23
    TREE_ITEM = 24
    CUSTOM = 25
    GROUP = 26
    THUMB = 27
    DATA_GRID = 28
    DATA_ITEM = 29
    DOCUMENT = 30
    SPLIT_BUTTON = 31
    WINDOW = 32
    PANE = 33
    HEADER = 34
    HEADER_ITEM = 35
    TABLE = 36
    TITLE_BAR = 37
    SEPARATOR = 38
    SEMANTIC_ZOOM = 39
    APP_BAR = 40

class AutomationEvents(enum.IntEnum):
    TOOL_TIP_OPENED = 0
    TOOL_TIP_CLOSED = 1
    MENU_OPENED = 2
    MENU_CLOSED = 3
    AUTOMATION_FOCUS_CHANGED = 4
    INVOKE_PATTERN_ON_INVOKED = 5
    SELECTION_ITEM_PATTERN_ON_ELEMENT_ADDED_TO_SELECTION = 6
    SELECTION_ITEM_PATTERN_ON_ELEMENT_REMOVED_FROM_SELECTION = 7
    SELECTION_ITEM_PATTERN_ON_ELEMENT_SELECTED = 8
    SELECTION_PATTERN_ON_INVALIDATED = 9
    TEXT_PATTERN_ON_TEXT_SELECTION_CHANGED = 10
    TEXT_PATTERN_ON_TEXT_CHANGED = 11
    ASYNC_CONTENT_LOADED = 12
    PROPERTY_CHANGED = 13
    STRUCTURE_CHANGED = 14
    DRAG_START = 15
    DRAG_CANCEL = 16
    DRAG_COMPLETE = 17
    DRAG_ENTER = 18
    DRAG_LEAVE = 19
    DROPPED = 20
    LIVE_REGION_CHANGED = 21
    INPUT_REACHED_TARGET = 22
    INPUT_REACHED_OTHER_ELEMENT = 23
    INPUT_DISCARDED = 24
    WINDOW_CLOSED = 25
    WINDOW_OPENED = 26
    CONVERSION_TARGET_CHANGED = 27
    TEXT_EDIT_TEXT_CHANGED = 28
    LAYOUT_INVALIDATED = 29

class AutomationHeadingLevel(enum.IntEnum):
    NONE = 0
    LEVEL1 = 1
    LEVEL2 = 2
    LEVEL3 = 3
    LEVEL4 = 4
    LEVEL5 = 5
    LEVEL6 = 6
    LEVEL7 = 7
    LEVEL8 = 8
    LEVEL9 = 9

class AutomationLandmarkType(enum.IntEnum):
    NONE = 0
    CUSTOM = 1
    FORM = 2
    MAIN = 3
    NAVIGATION = 4
    SEARCH = 5

class AutomationLiveSetting(enum.IntEnum):
    OFF = 0
    POLITE = 1
    ASSERTIVE = 2

class AutomationNavigationDirection(enum.IntEnum):
    PARENT = 0
    NEXT_SIBLING = 1
    PREVIOUS_SIBLING = 2
    FIRST_CHILD = 3
    LAST_CHILD = 4

class AutomationNotificationKind(enum.IntEnum):
    ITEM_ADDED = 0
    ITEM_REMOVED = 1
    ACTION_COMPLETED = 2
    ACTION_ABORTED = 3
    OTHER = 4

class AutomationNotificationProcessing(enum.IntEnum):
    IMPORTANT_ALL = 0
    IMPORTANT_MOST_RECENT = 1
    ALL = 2
    MOST_RECENT = 3
    CURRENT_THEN_MOST_RECENT = 4

class AutomationOrientation(enum.IntEnum):
    NONE = 0
    HORIZONTAL = 1
    VERTICAL = 2

class AutomationStructureChangeType(enum.IntEnum):
    CHILD_ADDED = 0
    CHILD_REMOVED = 1
    CHILDREN_INVALIDATED = 2
    CHILDREN_BULK_ADDED = 3
    CHILDREN_BULK_REMOVED = 4
    CHILDREN_REORDERED = 5

class PatternInterface(enum.IntEnum):
    INVOKE = 0
    SELECTION = 1
    VALUE = 2
    RANGE_VALUE = 3
    SCROLL = 4
    SCROLL_ITEM = 5
    EXPAND_COLLAPSE = 6
    GRID = 7
    GRID_ITEM = 8
    MULTIPLE_VIEW = 9
    WINDOW = 10
    SELECTION_ITEM = 11
    DOCK = 12
    TABLE = 13
    TABLE_ITEM = 14
    TOGGLE = 15
    TRANSFORM = 16
    TEXT = 17
    ITEM_CONTAINER = 18
    VIRTUALIZED_ITEM = 19
    TEXT2 = 20
    TEXT_CHILD = 21
    TEXT_RANGE = 22
    ANNOTATION = 23
    DRAG = 24
    DROP_TARGET = 25
    OBJECT_MODEL = 26
    SPREADSHEET = 27
    SPREADSHEET_ITEM = 28
    STYLES = 29
    TRANSFORM2 = 30
    SYNCHRONIZED_INPUT = 31
    TEXT_EDIT = 32
    CUSTOM_NAVIGATION = 33




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.ui.xaml as windows_ui_xaml
import winrt.windows.ui.xaml.automation as windows_ui_xaml_automation
import winrt.windows.ui.xaml.automation.provider as windows_ui_xaml_automation_provider
import winrt.windows.ui.xaml.controls as windows_ui_xaml_controls
import winrt.windows.ui.xaml.controls.primitives as windows_ui_xaml_controls_primitives

from winrt.windows.ui.xaml.automation.peers import AccessibilityView, AutomationControlType, AutomationEvents, AutomationHeadingLevel, AutomationLandmarkType, AutomationLiveSetting, AutomationNavigationDirection, AutomationNotificationKind, AutomationNotificationProcessing, AutomationOrientation, AutomationStructureChangeType, PatternInterface

Self = typing.TypeVar('Self')

@typing.final
class RawElementProviderRuntimeId:
    @_property
    def part1(self) -> winrt.system.UInt32: ...
    @_property
    def part2(self) -> winrt.system.UInt32: ...
    def __new__(cls, part1: winrt.system.UInt32 = 0, part2: winrt.system.UInt32 = 0) -> RawElementProviderRuntimeId: ...
    def __replace__(self, /, **changes: typing.Any) -> RawElementProviderRuntimeId: ...
    def unpack(self) -> typing.Tuple[winrt.system.UInt32, winrt.system.UInt32]: ...

class AppBarAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class AppBarAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IWindowProvider, windows_ui_xaml_automation_provider.IExpandCollapseProvider, windows_ui_xaml_automation_provider.IToggleProvider, metaclass=AppBarAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.AppBar) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::Close()
    def close(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::Expand()
    def expand(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::SetVisualState(Windows.UI.Xaml.Automation.WindowVisualState)
    def set_visual_state(self, state: windows_ui_xaml_automation.WindowVisualState, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::Toggle()
    def toggle(self) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::WaitForInputIdle(System.Int32)
    def wait_for_input_idle(self, milliseconds: winrt.system.Int32, /) -> bool: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_ExpandCollapseState()
    @_property
    @typing.final
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...
    # Windows.UI.Xaml.Automation.ToggleState Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_ToggleState()
    @_property
    @typing.final
    def toggle_state(self) -> windows_ui_xaml_automation.ToggleState: ...
    # Windows.UI.Xaml.Automation.WindowInteractionState Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_InteractionState()
    @_property
    @typing.final
    def interaction_state(self) -> windows_ui_xaml_automation.WindowInteractionState: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_IsModal()
    @_property
    @typing.final
    def is_modal(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_IsTopmost()
    @_property
    @typing.final
    def is_topmost(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_Maximizable()
    @_property
    @typing.final
    def maximizable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_Minimizable()
    @_property
    @typing.final
    def minimizable(self) -> bool: ...
    # Windows.UI.Xaml.Automation.WindowVisualState Windows.UI.Xaml.Automation.Peers.AppBarAutomationPeer::get_VisualState()
    @_property
    @typing.final
    def visual_state(self) -> windows_ui_xaml_automation.WindowVisualState: ...

class AppBarButtonAutomationPeer_Static(ButtonAutomationPeer_Static):
    pass

class AppBarButtonAutomationPeer(ButtonAutomationPeer, windows_ui_xaml_automation_provider.IExpandCollapseProvider, metaclass=AppBarButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.AppBarButton) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarButtonAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AppBarButtonAutomationPeer::Expand()
    def expand(self) -> None: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.AppBarButtonAutomationPeer::get_ExpandCollapseState()
    @_property
    @typing.final
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...

class AppBarToggleButtonAutomationPeer_Static(ToggleButtonAutomationPeer_Static):
    pass

class AppBarToggleButtonAutomationPeer(ToggleButtonAutomationPeer, metaclass=AppBarToggleButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.AppBarToggleButton) -> Self: ...

@typing.final
class AutoSuggestBoxAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.AutoSuggestBox) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutoSuggestBoxAutomationPeer::Invoke()
    def invoke(self) -> None: ...

class AutomationPeer_Static(windows_ui_xaml.DependencyObject_Static):
    # Windows.UI.Xaml.Automation.Peers.RawElementProviderRuntimeId Windows.UI.Xaml.Automation.Peers.AutomationPeer::GenerateRawElementProviderRuntimeId()
    def generate_raw_element_provider_runtime_id(cls) -> RawElementProviderRuntimeId: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::ListenerExists(Windows.UI.Xaml.Automation.Peers.AutomationEvents)
    def listener_exists(cls, event_id: AutomationEvents, /) -> bool: ...

class AutomationPeer(windows_ui_xaml.DependencyObject, metaclass=AutomationPeer_Static):
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAcceleratorKey()
    def get_accelerator_key(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAcceleratorKeyCore()
    def _get_accelerator_key_core(self) -> str: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAccessKey()
    def get_access_key(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAccessKeyCore()
    def _get_access_key_core(self) -> str: ...
    @typing.final
    # Windows.Foundation.Collections.IVector`1<Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAnnotations()
    def get_annotations(self) -> typing.MutableSequence[AutomationPeerAnnotation]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAnnotationsCore()
    def _get_annotations_core(self) -> typing.MutableSequence[AutomationPeerAnnotation]: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationControlType Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAutomationControlType()
    def get_automation_control_type(self) -> AutomationControlType: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationControlType Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAutomationControlTypeCore()
    def _get_automation_control_type_core(self) -> AutomationControlType: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAutomationId()
    def get_automation_id(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetAutomationIdCore()
    def _get_automation_id_core(self) -> str: ...
    @typing.final
    # Windows.Foundation.Rect Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetBoundingRectangle()
    def get_bounding_rectangle(self) -> windows_foundation.Rect: ...
    # Windows.Foundation.Rect Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetBoundingRectangleCore()
    def _get_bounding_rectangle_core(self) -> windows_foundation.Rect: ...
    @typing.final
    # Windows.Foundation.Collections.IVector`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetChildren()
    def get_children(self) -> typing.MutableSequence[AutomationPeer]: ...
    # Windows.Foundation.Collections.IVector`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetChildrenCore()
    def _get_children_core(self) -> typing.MutableSequence[AutomationPeer]: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetClassName()
    def get_class_name(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetClassNameCore()
    def _get_class_name_core(self) -> str: ...
    @typing.final
    # Windows.Foundation.Point Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetClickablePoint()
    def get_clickable_point(self) -> windows_foundation.Point: ...
    # Windows.Foundation.Point Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetClickablePointCore()
    def _get_clickable_point_core(self) -> windows_foundation.Point: ...
    @typing.final
    # Windows.Foundation.Collections.IVectorView`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetControlledPeers()
    def get_controlled_peers(self) -> typing.Sequence[AutomationPeer]: ...
    # Windows.Foundation.Collections.IVectorView`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetControlledPeersCore()
    def _get_controlled_peers_core(self) -> typing.Sequence[AutomationPeer]: ...
    @typing.final
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetCulture()
    def get_culture(self) -> winrt.system.Int32: ...
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetCultureCore()
    def _get_culture_core(self) -> winrt.system.Int32: ...
    # Windows.Foundation.Collections.IIterable`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetDescribedByCore()
    def _get_described_by_core(self) -> typing.Iterable[AutomationPeer]: ...
    @typing.final
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetElementFromPoint(Windows.Foundation.Point)
    def get_element_from_point(self, point_in_window_coordinates: typing.Union[windows_foundation.Point, typing.Tuple[winrt.system.Single, winrt.system.Single]], /) -> winrt.system.Object: ...
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetElementFromPointCore(Windows.Foundation.Point)
    def _get_element_from_point_core(self, point_in_window_coordinates: typing.Union[windows_foundation.Point, typing.Tuple[winrt.system.Single, winrt.system.Single]], /) -> winrt.system.Object: ...
    # Windows.Foundation.Collections.IIterable`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFlowsFromCore()
    def _get_flows_from_core(self) -> typing.Iterable[AutomationPeer]: ...
    # Windows.Foundation.Collections.IIterable`1<Windows.UI.Xaml.Automation.Peers.AutomationPeer> Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFlowsToCore()
    def _get_flows_to_core(self) -> typing.Iterable[AutomationPeer]: ...
    @typing.final
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFocusedElement()
    def get_focused_element(self) -> winrt.system.Object: ...
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFocusedElementCore()
    def _get_focused_element_core(self) -> winrt.system.Object: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFullDescription()
    def get_full_description(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetFullDescriptionCore()
    def _get_full_description_core(self) -> str: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationHeadingLevel Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetHeadingLevel()
    def get_heading_level(self) -> AutomationHeadingLevel: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationHeadingLevel Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetHeadingLevelCore()
    def _get_heading_level_core(self) -> AutomationHeadingLevel: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetHelpText()
    def get_help_text(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetHelpTextCore()
    def _get_help_text_core(self) -> str: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetItemStatus()
    def get_item_status(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetItemStatusCore()
    def _get_item_status_core(self) -> str: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetItemType()
    def get_item_type(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetItemTypeCore()
    def _get_item_type_core(self) -> str: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLabeledBy()
    def get_labeled_by(self) -> AutomationPeer: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLabeledByCore()
    def _get_labeled_by_core(self) -> AutomationPeer: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationLandmarkType Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLandmarkType()
    def get_landmark_type(self) -> AutomationLandmarkType: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationLandmarkType Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLandmarkTypeCore()
    def _get_landmark_type_core(self) -> AutomationLandmarkType: ...
    @typing.final
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLevel()
    def get_level(self) -> winrt.system.Int32: ...
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLevelCore()
    def _get_level_core(self) -> winrt.system.Int32: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationLiveSetting Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLiveSetting()
    def get_live_setting(self) -> AutomationLiveSetting: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationLiveSetting Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLiveSettingCore()
    def _get_live_setting_core(self) -> AutomationLiveSetting: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLocalizedControlType()
    def get_localized_control_type(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLocalizedControlTypeCore()
    def _get_localized_control_type_core(self) -> str: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLocalizedLandmarkType()
    def get_localized_landmark_type(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetLocalizedLandmarkTypeCore()
    def _get_localized_landmark_type_core(self) -> str: ...
    @typing.final
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetName()
    def get_name(self) -> str: ...
    # System.String Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetNameCore()
    def _get_name_core(self) -> str: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationOrientation Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetOrientation()
    def get_orientation(self) -> AutomationOrientation: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationOrientation Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetOrientationCore()
    def _get_orientation_core(self) -> AutomationOrientation: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetParent()
    # @deprecated("Consider using Navigate with AutomationNavigationDirection::Parent, which is an improved version of GetParent. For more info, see MSDN.")
    def get_parent(self) -> AutomationPeer: ...
    @typing.final
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPattern(Windows.UI.Xaml.Automation.Peers.PatternInterface)
    def get_pattern(self, pattern_interface: PatternInterface, /) -> winrt.system.Object: ...
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPatternCore(Windows.UI.Xaml.Automation.Peers.PatternInterface)
    def _get_pattern_core(self, pattern_interface: PatternInterface, /) -> winrt.system.Object: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPeerFromPoint(Windows.Foundation.Point)
    # @deprecated("Consider using GetElementFromPoint, which is an improved version of GetPeerFromPoint. For more info, see MSDN.")
    def get_peer_from_point(self, point: typing.Union[windows_foundation.Point, typing.Tuple[winrt.system.Single, winrt.system.Single]], /) -> AutomationPeer: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPeerFromPointCore(Windows.Foundation.Point)
    def _get_peer_from_point_core(self, point: typing.Union[windows_foundation.Point, typing.Tuple[winrt.system.Single, winrt.system.Single]], /) -> AutomationPeer: ...
    @typing.final
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPositionInSet()
    def get_position_in_set(self) -> winrt.system.Int32: ...
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetPositionInSetCore()
    def _get_position_in_set_core(self) -> winrt.system.Int32: ...
    @typing.final
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetSizeOfSet()
    def get_size_of_set(self) -> winrt.system.Int32: ...
    # System.Int32 Windows.UI.Xaml.Automation.Peers.AutomationPeer::GetSizeOfSetCore()
    def _get_size_of_set_core(self) -> winrt.system.Int32: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::HasKeyboardFocus()
    def has_keyboard_focus(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::HasKeyboardFocusCore()
    def _has_keyboard_focus_core(self) -> bool: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::InvalidatePeer()
    def invalidate_peer(self) -> None: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsContentElement()
    def is_content_element(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsContentElementCore()
    def _is_content_element_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsControlElement()
    def is_control_element(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsControlElementCore()
    def _is_control_element_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsDataValidForForm()
    def is_data_valid_for_form(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsDataValidForFormCore()
    def _is_data_valid_for_form_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsDialog()
    def is_dialog(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsDialogCore()
    def _is_dialog_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsEnabled()
    def is_enabled(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsEnabledCore()
    def _is_enabled_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsKeyboardFocusable()
    def is_keyboard_focusable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsKeyboardFocusableCore()
    def _is_keyboard_focusable_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsOffscreen()
    def is_offscreen(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsOffscreenCore()
    def _is_offscreen_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsPassword()
    def is_password(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsPasswordCore()
    def _is_password_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsPeripheral()
    def is_peripheral(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsPeripheralCore()
    def _is_peripheral_core(self) -> bool: ...
    @typing.final
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsRequiredForForm()
    def is_required_for_form(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.AutomationPeer::IsRequiredForFormCore()
    def _is_required_for_form_core(self) -> bool: ...
    @typing.final
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::Navigate(Windows.UI.Xaml.Automation.Peers.AutomationNavigationDirection)
    def navigate(self, direction: AutomationNavigationDirection, /) -> winrt.system.Object: ...
    # System.Object Windows.UI.Xaml.Automation.Peers.AutomationPeer::NavigateCore(Windows.UI.Xaml.Automation.Peers.AutomationNavigationDirection)
    def _navigate_core(self, direction: AutomationNavigationDirection, /) -> winrt.system.Object: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::PeerFromProvider(Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple)
    def _peer_from_provider(self, provider: windows_ui_xaml_automation_provider.IRawElementProviderSimple, /) -> AutomationPeer: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.AutomationPeer::ProviderFromPeer(Windows.UI.Xaml.Automation.Peers.AutomationPeer)
    def _provider_from_peer(self, peer: AutomationPeer, /) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::RaiseAutomationEvent(Windows.UI.Xaml.Automation.Peers.AutomationEvents)
    def raise_automation_event(self, event_id: AutomationEvents, /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::RaiseNotificationEvent(Windows.UI.Xaml.Automation.Peers.AutomationNotificationKind,Windows.UI.Xaml.Automation.Peers.AutomationNotificationProcessing,System.String,System.String)
    def raise_notification_event(self, notification_kind: AutomationNotificationKind, notification_processing: AutomationNotificationProcessing, display_string: str, activity_id: str, /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::RaisePropertyChangedEvent(Windows.UI.Xaml.Automation.AutomationProperty,System.Object,System.Object)
    def raise_property_changed_event(self, automation_property: windows_ui_xaml_automation.AutomationProperty, old_value: winrt.system.Object, new_value: winrt.system.Object, /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::RaiseStructureChangedEvent(Windows.UI.Xaml.Automation.Peers.AutomationStructureChangeType,Windows.UI.Xaml.Automation.Peers.AutomationPeer)
    def raise_structure_changed_event(self, structure_change_type: AutomationStructureChangeType, child: AutomationPeer, /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::RaiseTextEditTextChangedEvent(Windows.UI.Xaml.Automation.AutomationTextEditChangeType,Windows.Foundation.Collections.IVectorView`1<System.String>)
    def raise_text_edit_text_changed_event(self, automation_text_edit_change_type: windows_ui_xaml_automation.AutomationTextEditChangeType, changed_data: typing.Sequence[str], /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::SetFocus()
    def set_focus(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::SetFocusCore()
    def _set_focus_core(self) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::SetParent(Windows.UI.Xaml.Automation.Peers.AutomationPeer)
    def set_parent(self, peer: AutomationPeer, /) -> None: ...
    @typing.final
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::ShowContextMenu()
    def show_context_menu(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::ShowContextMenuCore()
    def _show_context_menu_core(self) -> None: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeer::get_EventsSource()
    @_property
    def events_source(self) -> AutomationPeer: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeer::put_EventsSource(Windows.UI.Xaml.Automation.Peers.AutomationPeer)
    @events_source.setter
    @typing.final
    def events_source(self, value: AutomationPeer) -> None: ...

@typing.final
class AutomationPeerAnnotation_Static(windows_ui_xaml.DependencyObject_Static):
    # Windows.UI.Xaml.DependencyProperty Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::get_PeerProperty()
    @_property
    def peer_property(cls) -> windows_ui_xaml.DependencyProperty: ...
    # Windows.UI.Xaml.DependencyProperty Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::get_TypeProperty()
    @_property
    def type_property(cls) -> windows_ui_xaml.DependencyProperty: ...

@typing.final
class AutomationPeerAnnotation(windows_ui_xaml.DependencyObject, metaclass=AutomationPeerAnnotation_Static):
    @typing.overload
    def __new__(cls: typing.Type[Self], type: windows_ui_xaml_automation.AnnotationType) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self], type: windows_ui_xaml_automation.AnnotationType, peer: AutomationPeer) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.UI.Xaml.Automation.AnnotationType Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::get_Type()
    @_property
    def type(self) -> windows_ui_xaml_automation.AnnotationType: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::put_Type(Windows.UI.Xaml.Automation.AnnotationType)
    @type.setter
    def type(self, value: windows_ui_xaml_automation.AnnotationType) -> None: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::get_Peer()
    @_property
    def peer(self) -> AutomationPeer: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.AutomationPeerAnnotation::put_Peer(Windows.UI.Xaml.Automation.Peers.AutomationPeer)
    @peer.setter
    def peer(self, value: AutomationPeer) -> None: ...

class ButtonAutomationPeer_Static(ButtonBaseAutomationPeer_Static):
    pass

class ButtonAutomationPeer(ButtonBaseAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider, metaclass=ButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.Button) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ButtonAutomationPeer::Invoke()
    def invoke(self) -> None: ...

class ButtonBaseAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ButtonBaseAutomationPeer(FrameworkElementAutomationPeer, metaclass=ButtonBaseAutomationPeer_Static):
    pass

class CalendarDatePickerAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class CalendarDatePickerAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IValueProvider, windows_ui_xaml_automation_provider.IInvokeProvider, metaclass=CalendarDatePickerAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.CalendarDatePicker) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.CalendarDatePickerAutomationPeer::Invoke()
    def invoke(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.CalendarDatePickerAutomationPeer::SetValue(System.String)
    def set_value(self, value: str, /) -> None: ...  # type: ignore[misc,override]
    # System.Boolean Windows.UI.Xaml.Automation.Peers.CalendarDatePickerAutomationPeer::get_IsReadOnly()
    @_property
    @typing.final
    def is_read_only(self) -> bool: ...
    # System.String Windows.UI.Xaml.Automation.Peers.CalendarDatePickerAutomationPeer::get_Value()
    @_property
    @typing.final
    def value(self) -> str: ...

class CaptureElementAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class CaptureElementAutomationPeer(FrameworkElementAutomationPeer, metaclass=CaptureElementAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.CaptureElement) -> Self: ...

class CheckBoxAutomationPeer_Static(ToggleButtonAutomationPeer_Static):
    pass

class CheckBoxAutomationPeer(ToggleButtonAutomationPeer, metaclass=CheckBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.CheckBox) -> Self: ...

class ColorPickerSliderAutomationPeer_Static(SliderAutomationPeer_Static):
    pass

class ColorPickerSliderAutomationPeer(SliderAutomationPeer, metaclass=ColorPickerSliderAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.ColorPickerSlider) -> Self: ...

class ColorSpectrumAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ColorSpectrumAutomationPeer(FrameworkElementAutomationPeer, metaclass=ColorSpectrumAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.ColorSpectrum) -> Self: ...

class ComboBoxAutomationPeer_Static(SelectorAutomationPeer_Static):
    pass

class ComboBoxAutomationPeer(SelectorAutomationPeer, windows_ui_xaml_automation_provider.IWindowProvider, windows_ui_xaml_automation_provider.IExpandCollapseProvider, windows_ui_xaml_automation_provider.IValueProvider, metaclass=ComboBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ComboBox) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::Close()
    def close(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::Expand()
    def expand(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::SetValue(System.String)
    def set_value(self, value: str, /) -> None: ...  # type: ignore[misc,override]
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::SetVisualState(Windows.UI.Xaml.Automation.WindowVisualState)
    def set_visual_state(self, state: windows_ui_xaml_automation.WindowVisualState, /) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::WaitForInputIdle(System.Int32)
    def wait_for_input_idle(self, milliseconds: winrt.system.Int32, /) -> bool: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_ExpandCollapseState()
    @_property
    @typing.final
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_IsReadOnly()
    @_property
    @typing.final
    def is_read_only(self) -> bool: ...
    # System.String Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_Value()
    @_property
    @typing.final
    def value(self) -> str: ...
    # Windows.UI.Xaml.Automation.WindowInteractionState Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_InteractionState()
    @_property
    @typing.final
    def interaction_state(self) -> windows_ui_xaml_automation.WindowInteractionState: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_IsModal()
    @_property
    @typing.final
    def is_modal(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_IsTopmost()
    @_property
    @typing.final
    def is_topmost(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_Maximizable()
    @_property
    @typing.final
    def maximizable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_Minimizable()
    @_property
    @typing.final
    def minimizable(self) -> bool: ...
    # Windows.UI.Xaml.Automation.WindowVisualState Windows.UI.Xaml.Automation.Peers.ComboBoxAutomationPeer::get_VisualState()
    @_property
    @typing.final
    def visual_state(self) -> windows_ui_xaml_automation.WindowVisualState: ...

class ComboBoxItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ComboBoxItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=ComboBoxItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ComboBoxItem) -> Self: ...

class ComboBoxItemDataAutomationPeer_Static(SelectorItemAutomationPeer_Static):
    pass

class ComboBoxItemDataAutomationPeer(SelectorItemAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=ComboBoxItemDataAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: ComboBoxAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ComboBoxItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

class DatePickerAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class DatePickerAutomationPeer(FrameworkElementAutomationPeer, metaclass=DatePickerAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.DatePicker) -> Self: ...

@typing.final
class DatePickerFlyoutPresenterAutomationPeer(FrameworkElementAutomationPeer):
    pass

class FlipViewAutomationPeer_Static(SelectorAutomationPeer_Static):
    pass

class FlipViewAutomationPeer(SelectorAutomationPeer, metaclass=FlipViewAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.FlipView) -> Self: ...

class FlipViewItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class FlipViewItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=FlipViewItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.FlipViewItem) -> Self: ...

class FlipViewItemDataAutomationPeer_Static(SelectorItemAutomationPeer_Static):
    pass

class FlipViewItemDataAutomationPeer(SelectorItemAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=FlipViewItemDataAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: FlipViewAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.FlipViewItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

class FlyoutPresenterAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class FlyoutPresenterAutomationPeer(FrameworkElementAutomationPeer, metaclass=FlyoutPresenterAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.FlyoutPresenter) -> Self: ...

class FrameworkElementAutomationPeer_Static(AutomationPeer_Static):
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.FrameworkElementAutomationPeer::CreatePeerForElement(Windows.UI.Xaml.UIElement)
    def create_peer_for_element(cls, element: windows_ui_xaml.UIElement, /) -> AutomationPeer: ...
    # Windows.UI.Xaml.Automation.Peers.AutomationPeer Windows.UI.Xaml.Automation.Peers.FrameworkElementAutomationPeer::FromElement(Windows.UI.Xaml.UIElement)
    def from_element(cls, element: windows_ui_xaml.UIElement, /) -> AutomationPeer: ...

class FrameworkElementAutomationPeer(AutomationPeer, metaclass=FrameworkElementAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml.FrameworkElement) -> Self: ...
    # Windows.UI.Xaml.UIElement Windows.UI.Xaml.Automation.Peers.FrameworkElementAutomationPeer::get_Owner()
    @_property
    @typing.final
    def owner(self) -> windows_ui_xaml.UIElement: ...

class GridViewAutomationPeer_Static(ListViewBaseAutomationPeer_Static):
    pass

class GridViewAutomationPeer(ListViewBaseAutomationPeer, metaclass=GridViewAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.GridView) -> Self: ...

class GridViewHeaderItemAutomationPeer_Static(ListViewBaseHeaderItemAutomationPeer_Static):
    pass

class GridViewHeaderItemAutomationPeer(ListViewBaseHeaderItemAutomationPeer, metaclass=GridViewHeaderItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.GridViewHeaderItem) -> Self: ...

class GridViewItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class GridViewItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=GridViewItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.GridViewItem) -> Self: ...

class GridViewItemDataAutomationPeer_Static(SelectorItemAutomationPeer_Static):
    pass

class GridViewItemDataAutomationPeer(SelectorItemAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=GridViewItemDataAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: GridViewAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.GridViewItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

class GroupItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class GroupItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=GroupItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.GroupItem) -> Self: ...

class HubAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class HubAutomationPeer(FrameworkElementAutomationPeer, metaclass=HubAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.Hub) -> Self: ...

class HubSectionAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class HubSectionAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=HubSectionAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.HubSection) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.HubSectionAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

class HyperlinkButtonAutomationPeer_Static(ButtonBaseAutomationPeer_Static):
    pass

class HyperlinkButtonAutomationPeer(ButtonBaseAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider, metaclass=HyperlinkButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.HyperlinkButton) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.HyperlinkButtonAutomationPeer::Invoke()
    def invoke(self) -> None: ...

class ImageAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ImageAutomationPeer(FrameworkElementAutomationPeer, metaclass=ImageAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.Image) -> Self: ...

@typing.final
class InkToolbarAutomationPeer(FrameworkElementAutomationPeer):
    pass

class ItemAutomationPeer_Static(AutomationPeer_Static):
    pass

class ItemAutomationPeer(AutomationPeer, windows_ui_xaml_automation_provider.IVirtualizedItemProvider, metaclass=ItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: ItemsControlAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ItemAutomationPeer::Realize()
    def realize(self) -> None: ...
    # System.Object Windows.UI.Xaml.Automation.Peers.ItemAutomationPeer::get_Item()
    @_property
    @typing.final
    def item(self) -> winrt.system.Object: ...
    # Windows.UI.Xaml.Automation.Peers.ItemsControlAutomationPeer Windows.UI.Xaml.Automation.Peers.ItemAutomationPeer::get_ItemsControlAutomationPeer()
    @_property
    @typing.final
    def items_control_automation_peer(self) -> ItemsControlAutomationPeer: ...

class ItemsControlAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ItemsControlAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IItemContainerProvider, metaclass=ItemsControlAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ItemsControl) -> Self: ...
    @typing.final
    # Windows.UI.Xaml.Automation.Peers.ItemAutomationPeer Windows.UI.Xaml.Automation.Peers.ItemsControlAutomationPeer::CreateItemAutomationPeer(System.Object)
    def create_item_automation_peer(self, item: winrt.system.Object, /) -> ItemAutomationPeer: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.ItemsControlAutomationPeer::FindItemByProperty(Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple,Windows.UI.Xaml.Automation.AutomationProperty,System.Object)
    def find_item_by_property(self, start_after: windows_ui_xaml_automation_provider.IRawElementProviderSimple, automation_property: windows_ui_xaml_automation.AutomationProperty, value: winrt.system.Object, /) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...
    # Windows.UI.Xaml.Automation.Peers.ItemAutomationPeer Windows.UI.Xaml.Automation.Peers.ItemsControlAutomationPeer::OnCreateItemAutomationPeer(System.Object)
    def _on_create_item_automation_peer(self, item: winrt.system.Object, /) -> ItemAutomationPeer: ...

class ListBoxAutomationPeer_Static(SelectorAutomationPeer_Static):
    pass

class ListBoxAutomationPeer(SelectorAutomationPeer, metaclass=ListBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListBox) -> Self: ...

class ListBoxItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ListBoxItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=ListBoxItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListBoxItem) -> Self: ...

class ListBoxItemDataAutomationPeer_Static(SelectorItemAutomationPeer_Static):
    pass

class ListBoxItemDataAutomationPeer(SelectorItemAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=ListBoxItemDataAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: ListBoxAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ListBoxItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

@typing.final
class ListPickerFlyoutPresenterAutomationPeer(FrameworkElementAutomationPeer):
    pass

class ListViewAutomationPeer_Static(ListViewBaseAutomationPeer_Static):
    pass

class ListViewAutomationPeer(ListViewBaseAutomationPeer, metaclass=ListViewAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListView) -> Self: ...

class ListViewBaseAutomationPeer_Static(SelectorAutomationPeer_Static):
    pass

class ListViewBaseAutomationPeer(SelectorAutomationPeer, windows_ui_xaml_automation_provider.IDropTargetProvider, metaclass=ListViewBaseAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListViewBase) -> Self: ...
    # System.String Windows.UI.Xaml.Automation.Peers.ListViewBaseAutomationPeer::get_DropEffect()
    @_property
    @typing.final
    def drop_effect(self) -> str: ...
    # System.String[] Windows.UI.Xaml.Automation.Peers.ListViewBaseAutomationPeer::get_DropEffects()
    @_property
    @typing.final
    def drop_effects(self) -> str: ...

class ListViewBaseHeaderItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ListViewBaseHeaderItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=ListViewBaseHeaderItemAutomationPeer_Static):
    pass

class ListViewHeaderItemAutomationPeer_Static(ListViewBaseHeaderItemAutomationPeer_Static):
    pass

class ListViewHeaderItemAutomationPeer(ListViewBaseHeaderItemAutomationPeer, metaclass=ListViewHeaderItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListViewHeaderItem) -> Self: ...

class ListViewItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ListViewItemAutomationPeer(FrameworkElementAutomationPeer, metaclass=ListViewItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ListViewItem) -> Self: ...

class ListViewItemDataAutomationPeer_Static(SelectorItemAutomationPeer_Static):
    pass

class ListViewItemDataAutomationPeer(SelectorItemAutomationPeer, windows_ui_xaml_automation_provider.IScrollItemProvider, metaclass=ListViewItemDataAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: ListViewBaseAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ListViewItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...

@typing.final
class LoopingSelectorAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IScrollProvider, windows_ui_xaml_automation_provider.IExpandCollapseProvider, windows_ui_xaml_automation_provider.IItemContainerProvider, windows_ui_xaml_automation_provider.ISelectionProvider):
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::Expand()
    def expand(self) -> None: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::FindItemByProperty(Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple,Windows.UI.Xaml.Automation.AutomationProperty,System.Object)
    def find_item_by_property(self, start_after: windows_ui_xaml_automation_provider.IRawElementProviderSimple, automation_property: windows_ui_xaml_automation.AutomationProperty, value: winrt.system.Object, /) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple[] Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::GetSelection()
    def get_selection(self) -> winrt.system.Array[windows_ui_xaml_automation_provider.IRawElementProviderSimple]: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::Scroll(Windows.UI.Xaml.Automation.ScrollAmount,Windows.UI.Xaml.Automation.ScrollAmount)
    def scroll(self, horizontal_amount: windows_ui_xaml_automation.ScrollAmount, vertical_amount: windows_ui_xaml_automation.ScrollAmount, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::SetScrollPercent(System.Double,System.Double)
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_ExpandCollapseState()
    @_property
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_HorizontalScrollPercent()
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_HorizontalViewSize()
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_HorizontallyScrollable()
    @_property
    def horizontally_scrollable(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_VerticalScrollPercent()
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_VerticalViewSize()
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_VerticallyScrollable()
    @_property
    def vertically_scrollable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_CanSelectMultiple()
    @_property
    def can_select_multiple(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.LoopingSelectorAutomationPeer::get_IsSelectionRequired()
    @_property
    def is_selection_required(self) -> bool: ...

@typing.final
class LoopingSelectorItemAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.ISelectionItemProvider, windows_ui_xaml_automation_provider.IScrollItemProvider):
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::AddToSelection()
    def add_to_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::RemoveFromSelection()
    def remove_from_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::Select()
    def select(self) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::get_IsSelected()
    @_property
    def is_selected(self) -> bool: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemAutomationPeer::get_SelectionContainer()
    @_property
    def selection_container(self) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...

@typing.final
class LoopingSelectorItemDataAutomationPeer(AutomationPeer, windows_ui_xaml_automation_provider.IVirtualizedItemProvider):
    # System.Void Windows.UI.Xaml.Automation.Peers.LoopingSelectorItemDataAutomationPeer::Realize()
    def realize(self) -> None: ...

@typing.final
class MapControlAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.ITransformProvider2, windows_ui_xaml_automation_provider.ITransformProvider, windows_ui_xaml_automation_provider.IScrollProvider):
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::Move(System.Double,System.Double)
    def move(self, x: winrt.system.Double, y: winrt.system.Double, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::Resize(System.Double,System.Double)
    def resize(self, width: winrt.system.Double, height: winrt.system.Double, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::Rotate(System.Double)
    def rotate(self, degrees: winrt.system.Double, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::Scroll(Windows.UI.Xaml.Automation.ScrollAmount,Windows.UI.Xaml.Automation.ScrollAmount)
    def scroll(self, horizontal_amount: windows_ui_xaml_automation.ScrollAmount, vertical_amount: windows_ui_xaml_automation.ScrollAmount, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::SetScrollPercent(System.Double,System.Double)
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::Zoom(System.Double)
    def zoom(self, zoom: winrt.system.Double, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::ZoomByUnit(Windows.UI.Xaml.Automation.ZoomUnit)
    def zoom_by_unit(self, zoom_unit: windows_ui_xaml_automation.ZoomUnit, /) -> None: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_HorizontalScrollPercent()
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_HorizontalViewSize()
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_HorizontallyScrollable()
    @_property
    def horizontally_scrollable(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_VerticalScrollPercent()
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_VerticalViewSize()
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_VerticallyScrollable()
    @_property
    def vertically_scrollable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_CanMove()
    @_property
    def can_move(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_CanResize()
    @_property
    def can_resize(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_CanRotate()
    @_property
    def can_rotate(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_CanZoom()
    @_property
    def can_zoom(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_MaxZoom()
    @_property
    def max_zoom(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_MinZoom()
    @_property
    def min_zoom(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.MapControlAutomationPeer::get_ZoomLevel()
    @_property
    def zoom_level(self) -> winrt.system.Double: ...

class MediaElementAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MediaElementAutomationPeer(FrameworkElementAutomationPeer, metaclass=MediaElementAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MediaElement) -> Self: ...

class MediaPlayerElementAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MediaPlayerElementAutomationPeer(FrameworkElementAutomationPeer, metaclass=MediaPlayerElementAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MediaPlayerElement) -> Self: ...

class MediaTransportControlsAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MediaTransportControlsAutomationPeer(FrameworkElementAutomationPeer, metaclass=MediaTransportControlsAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MediaTransportControls) -> Self: ...

class MenuBarAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MenuBarAutomationPeer(FrameworkElementAutomationPeer, metaclass=MenuBarAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MenuBar) -> Self: ...

class MenuBarItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MenuBarItemAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider, windows_ui_xaml_automation_provider.IExpandCollapseProvider, metaclass=MenuBarItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MenuBarItem) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MenuBarItemAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MenuBarItemAutomationPeer::Expand()
    def expand(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MenuBarItemAutomationPeer::Invoke()
    def invoke(self) -> None: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.MenuBarItemAutomationPeer::get_ExpandCollapseState()
    @_property
    @typing.final
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...

class MenuFlyoutItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class MenuFlyoutItemAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider, metaclass=MenuFlyoutItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MenuFlyoutItem) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.MenuFlyoutItemAutomationPeer::Invoke()
    def invoke(self) -> None: ...

class MenuFlyoutPresenterAutomationPeer_Static(ItemsControlAutomationPeer_Static):
    pass

class MenuFlyoutPresenterAutomationPeer(ItemsControlAutomationPeer, metaclass=MenuFlyoutPresenterAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.MenuFlyoutPresenter) -> Self: ...

class NavigationViewItemAutomationPeer_Static(ListViewItemAutomationPeer_Static):
    pass

class NavigationViewItemAutomationPeer(ListViewItemAutomationPeer, metaclass=NavigationViewItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.NavigationViewItem) -> Self: ...

class PasswordBoxAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class PasswordBoxAutomationPeer(FrameworkElementAutomationPeer, metaclass=PasswordBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.PasswordBox) -> Self: ...

class PersonPictureAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class PersonPictureAutomationPeer(FrameworkElementAutomationPeer, metaclass=PersonPictureAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.PersonPicture) -> Self: ...

@typing.final
class PickerFlyoutPresenterAutomationPeer(FrameworkElementAutomationPeer):
    pass

@typing.final
class PivotAutomationPeer(ItemsControlAutomationPeer, windows_ui_xaml_automation_provider.IScrollProvider, windows_ui_xaml_automation_provider.ISelectionProvider):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.Pivot) -> Self: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple[] Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::GetSelection()
    def get_selection(self) -> winrt.system.Array[windows_ui_xaml_automation_provider.IRawElementProviderSimple]: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::Scroll(Windows.UI.Xaml.Automation.ScrollAmount,Windows.UI.Xaml.Automation.ScrollAmount)
    def scroll(self, horizontal_amount: windows_ui_xaml_automation.ScrollAmount, vertical_amount: windows_ui_xaml_automation.ScrollAmount, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::SetScrollPercent(System.Double,System.Double)
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_HorizontalScrollPercent()
    @_property
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_HorizontalViewSize()
    @_property
    def horizontal_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_HorizontallyScrollable()
    @_property
    def horizontally_scrollable(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_VerticalScrollPercent()
    @_property
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_VerticalViewSize()
    @_property
    def vertical_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_VerticallyScrollable()
    @_property
    def vertically_scrollable(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_CanSelectMultiple()
    @_property
    def can_select_multiple(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.PivotAutomationPeer::get_IsSelectionRequired()
    @_property
    def is_selection_required(self) -> bool: ...

@typing.final
class PivotItemAutomationPeer(FrameworkElementAutomationPeer):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.PivotItem) -> Self: ...

@typing.final
class PivotItemDataAutomationPeer(ItemAutomationPeer, windows_ui_xaml_automation_provider.IVirtualizedItemProvider, windows_ui_xaml_automation_provider.ISelectionItemProvider, windows_ui_xaml_automation_provider.IScrollItemProvider):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: PivotAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::AddToSelection()
    def add_to_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::Realize()
    def realize(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::RemoveFromSelection()
    def remove_from_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::ScrollIntoView()
    def scroll_into_view(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::Select()
    def select(self) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::get_IsSelected()
    @_property
    def is_selected(self) -> bool: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.PivotItemDataAutomationPeer::get_SelectionContainer()
    @_property
    def selection_container(self) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...

class ProgressBarAutomationPeer_Static(RangeBaseAutomationPeer_Static):
    pass

class ProgressBarAutomationPeer(RangeBaseAutomationPeer, metaclass=ProgressBarAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ProgressBar) -> Self: ...

class ProgressRingAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ProgressRingAutomationPeer(FrameworkElementAutomationPeer, metaclass=ProgressRingAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ProgressRing) -> Self: ...

class RadioButtonAutomationPeer_Static(ToggleButtonAutomationPeer_Static):
    pass

class RadioButtonAutomationPeer(ToggleButtonAutomationPeer, windows_ui_xaml_automation_provider.ISelectionItemProvider, metaclass=RadioButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.RadioButton) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.RadioButtonAutomationPeer::AddToSelection()
    def add_to_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.RadioButtonAutomationPeer::RemoveFromSelection()
    def remove_from_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.RadioButtonAutomationPeer::Select()
    def select(self) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.RadioButtonAutomationPeer::get_IsSelected()
    @_property
    @typing.final
    def is_selected(self) -> bool: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.RadioButtonAutomationPeer::get_SelectionContainer()
    @_property
    @typing.final
    def selection_container(self) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...

class RangeBaseAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class RangeBaseAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IRangeValueProvider, metaclass=RangeBaseAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.RangeBase) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::SetValue(System.Double)
    def set_value(self, value: winrt.system.Double, /) -> None: ...  # type: ignore[misc,override]
    # System.Boolean Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_IsReadOnly()
    @_property
    @typing.final
    def is_read_only(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_LargeChange()
    @_property
    @typing.final
    def large_change(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_Maximum()
    @_property
    @typing.final
    def maximum(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_Minimum()
    @_property
    @typing.final
    def minimum(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_SmallChange()
    @_property
    @typing.final
    def small_change(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.RangeBaseAutomationPeer::get_Value()
    @_property
    @typing.final
    def value(self) -> winrt.system.Double: ...

class RatingControlAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class RatingControlAutomationPeer(FrameworkElementAutomationPeer, metaclass=RatingControlAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.RatingControl) -> Self: ...

class RepeatButtonAutomationPeer_Static(ButtonBaseAutomationPeer_Static):
    pass

class RepeatButtonAutomationPeer(ButtonBaseAutomationPeer, windows_ui_xaml_automation_provider.IInvokeProvider, metaclass=RepeatButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.RepeatButton) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.RepeatButtonAutomationPeer::Invoke()
    def invoke(self) -> None: ...

class RichEditBoxAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class RichEditBoxAutomationPeer(FrameworkElementAutomationPeer, metaclass=RichEditBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.RichEditBox) -> Self: ...

class RichTextBlockAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class RichTextBlockAutomationPeer(FrameworkElementAutomationPeer, metaclass=RichTextBlockAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.RichTextBlock) -> Self: ...

class RichTextBlockOverflowAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class RichTextBlockOverflowAutomationPeer(FrameworkElementAutomationPeer, metaclass=RichTextBlockOverflowAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.RichTextBlockOverflow) -> Self: ...

class ScrollBarAutomationPeer_Static(RangeBaseAutomationPeer_Static):
    pass

class ScrollBarAutomationPeer(RangeBaseAutomationPeer, metaclass=ScrollBarAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.ScrollBar) -> Self: ...

class ScrollViewerAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ScrollViewerAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IScrollProvider, metaclass=ScrollViewerAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ScrollViewer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::Scroll(Windows.UI.Xaml.Automation.ScrollAmount,Windows.UI.Xaml.Automation.ScrollAmount)
    def scroll(self, horizontal_amount: windows_ui_xaml_automation.ScrollAmount, vertical_amount: windows_ui_xaml_automation.ScrollAmount, /) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::SetScrollPercent(System.Double,System.Double)
    def set_scroll_percent(self, horizontal_percent: winrt.system.Double, vertical_percent: winrt.system.Double, /) -> None: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_HorizontalScrollPercent()
    @_property
    @typing.final
    def horizontal_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_HorizontalViewSize()
    @_property
    @typing.final
    def horizontal_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_HorizontallyScrollable()
    @_property
    @typing.final
    def horizontally_scrollable(self) -> bool: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_VerticalScrollPercent()
    @_property
    @typing.final
    def vertical_scroll_percent(self) -> winrt.system.Double: ...
    # System.Double Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_VerticalViewSize()
    @_property
    @typing.final
    def vertical_view_size(self) -> winrt.system.Double: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.ScrollViewerAutomationPeer::get_VerticallyScrollable()
    @_property
    @typing.final
    def vertically_scrollable(self) -> bool: ...

class SearchBoxAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class SearchBoxAutomationPeer(FrameworkElementAutomationPeer, metaclass=SearchBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.SearchBox) -> Self: ...

class SelectorAutomationPeer_Static(ItemsControlAutomationPeer_Static):
    pass

class SelectorAutomationPeer(ItemsControlAutomationPeer, windows_ui_xaml_automation_provider.ISelectionProvider, metaclass=SelectorAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.Selector) -> Self: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple[] Windows.UI.Xaml.Automation.Peers.SelectorAutomationPeer::GetSelection()
    def get_selection(self) -> winrt.system.Array[windows_ui_xaml_automation_provider.IRawElementProviderSimple]: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.SelectorAutomationPeer::get_CanSelectMultiple()
    @_property
    @typing.final
    def can_select_multiple(self) -> bool: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.SelectorAutomationPeer::get_IsSelectionRequired()
    @_property
    @typing.final
    def is_selection_required(self) -> bool: ...

class SelectorItemAutomationPeer_Static(ItemAutomationPeer_Static):
    pass

class SelectorItemAutomationPeer(ItemAutomationPeer, windows_ui_xaml_automation_provider.ISelectionItemProvider, metaclass=SelectorItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], item: winrt.system.Object, parent: SelectorAutomationPeer) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.SelectorItemAutomationPeer::AddToSelection()
    def add_to_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.SelectorItemAutomationPeer::RemoveFromSelection()
    def remove_from_selection(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.SelectorItemAutomationPeer::Select()
    def select(self) -> None: ...
    # System.Boolean Windows.UI.Xaml.Automation.Peers.SelectorItemAutomationPeer::get_IsSelected()
    @_property
    @typing.final
    def is_selected(self) -> bool: ...
    # Windows.UI.Xaml.Automation.Provider.IRawElementProviderSimple Windows.UI.Xaml.Automation.Peers.SelectorItemAutomationPeer::get_SelectionContainer()
    @_property
    @typing.final
    def selection_container(self) -> windows_ui_xaml_automation_provider.IRawElementProviderSimple: ...

class SemanticZoomAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class SemanticZoomAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IToggleProvider, metaclass=SemanticZoomAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.SemanticZoom) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.SemanticZoomAutomationPeer::Toggle()
    def toggle(self) -> None: ...
    # Windows.UI.Xaml.Automation.ToggleState Windows.UI.Xaml.Automation.Peers.SemanticZoomAutomationPeer::get_ToggleState()
    @_property
    @typing.final
    def toggle_state(self) -> windows_ui_xaml_automation.ToggleState: ...

class SettingsFlyoutAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class SettingsFlyoutAutomationPeer(FrameworkElementAutomationPeer, metaclass=SettingsFlyoutAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.SettingsFlyout) -> Self: ...

class SliderAutomationPeer_Static(RangeBaseAutomationPeer_Static):
    pass

class SliderAutomationPeer(RangeBaseAutomationPeer, metaclass=SliderAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.Slider) -> Self: ...

class TextBlockAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class TextBlockAutomationPeer(FrameworkElementAutomationPeer, metaclass=TextBlockAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.TextBlock) -> Self: ...

class TextBoxAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class TextBoxAutomationPeer(FrameworkElementAutomationPeer, metaclass=TextBoxAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.TextBox) -> Self: ...

class ThumbAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ThumbAutomationPeer(FrameworkElementAutomationPeer, metaclass=ThumbAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.Thumb) -> Self: ...

class TimePickerAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class TimePickerAutomationPeer(FrameworkElementAutomationPeer, metaclass=TimePickerAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.TimePicker) -> Self: ...

@typing.final
class TimePickerFlyoutPresenterAutomationPeer(FrameworkElementAutomationPeer):
    pass

class ToggleButtonAutomationPeer_Static(ButtonBaseAutomationPeer_Static):
    pass

class ToggleButtonAutomationPeer(ButtonBaseAutomationPeer, windows_ui_xaml_automation_provider.IToggleProvider, metaclass=ToggleButtonAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls_primitives.ToggleButton) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ToggleButtonAutomationPeer::Toggle()
    def toggle(self) -> None: ...
    # Windows.UI.Xaml.Automation.ToggleState Windows.UI.Xaml.Automation.Peers.ToggleButtonAutomationPeer::get_ToggleState()
    @_property
    @typing.final
    def toggle_state(self) -> windows_ui_xaml_automation.ToggleState: ...

class ToggleMenuFlyoutItemAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ToggleMenuFlyoutItemAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IToggleProvider, metaclass=ToggleMenuFlyoutItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ToggleMenuFlyoutItem) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ToggleMenuFlyoutItemAutomationPeer::Toggle()
    def toggle(self) -> None: ...
    # Windows.UI.Xaml.Automation.ToggleState Windows.UI.Xaml.Automation.Peers.ToggleMenuFlyoutItemAutomationPeer::get_ToggleState()
    @_property
    @typing.final
    def toggle_state(self) -> windows_ui_xaml_automation.ToggleState: ...

class ToggleSwitchAutomationPeer_Static(FrameworkElementAutomationPeer_Static):
    pass

class ToggleSwitchAutomationPeer(FrameworkElementAutomationPeer, windows_ui_xaml_automation_provider.IToggleProvider, metaclass=ToggleSwitchAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.ToggleSwitch) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.ToggleSwitchAutomationPeer::Toggle()
    def toggle(self) -> None: ...
    # Windows.UI.Xaml.Automation.ToggleState Windows.UI.Xaml.Automation.Peers.ToggleSwitchAutomationPeer::get_ToggleState()
    @_property
    @typing.final
    def toggle_state(self) -> windows_ui_xaml_automation.ToggleState: ...

class TreeViewItemAutomationPeer_Static(ListViewItemAutomationPeer_Static):
    pass

class TreeViewItemAutomationPeer(ListViewItemAutomationPeer, windows_ui_xaml_automation_provider.IExpandCollapseProvider, metaclass=TreeViewItemAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.TreeViewItem) -> Self: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.TreeViewItemAutomationPeer::Collapse()
    def collapse(self) -> None: ...
    # System.Void Windows.UI.Xaml.Automation.Peers.TreeViewItemAutomationPeer::Expand()
    def expand(self) -> None: ...
    # Windows.UI.Xaml.Automation.ExpandCollapseState Windows.UI.Xaml.Automation.Peers.TreeViewItemAutomationPeer::get_ExpandCollapseState()
    @_property
    @typing.final
    def expand_collapse_state(self) -> windows_ui_xaml_automation.ExpandCollapseState: ...

class TreeViewListAutomationPeer_Static(SelectorAutomationPeer_Static):
    pass

class TreeViewListAutomationPeer(SelectorAutomationPeer, metaclass=TreeViewListAutomationPeer_Static):
    def __new__(cls: typing.Type[Self], owner: windows_ui_xaml_controls.TreeViewList) -> Self: ...

